/*
 * Copyright 2009-2010 the Fess Project and the Others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package jp.sf.fess.db.exentity;

import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.List;
import java.util.regex.Pattern;

import jp.sf.fess.Constants;
import jp.sf.fess.db.bsentity.BsFileCrawlingConfig;

import org.seasar.framework.util.StringUtil;

/**
 * The entity of FILE_CRAWLING_CONFIG.
 * <p>
 * You can implement your original methods here.
 * This class remains when re-generating.
 * </p>
 * @author DBFlute(AutoGenerator)
 */
public class FileCrawlingConfig extends BsFileCrawlingConfig implements
        CrawlingConfig {

    /** Serial version UID. (Default) */
    private static final long serialVersionUID = 1L;

    private String[] browserTypeIds;

    private String[] labelTypeIds;

    private String[] roleTypeIds;

    protected Pattern[] includedDocPathPatterns;

    protected Pattern[] excludedDocPathPatterns;

    public FileCrawlingConfig() {
        super();
        setBoost(BigDecimal.ONE);
    }

    public String[] getBrowserTypeIds() {
        return browserTypeIds;
    }

    public void setBrowserTypeIds(String[] browserTypeIds) {
        this.browserTypeIds = browserTypeIds;
    }

    @Override
    public String[] getBrowserTypeValues() {
        List<String> values = new ArrayList<String>();
        List<FileConfigToBrowserTypeMapping> list = getFileConfigToBrowserTypeMappingList();
        if (list != null && !list.isEmpty()) {
            for (FileConfigToBrowserTypeMapping mapping : list) {
                values.add(mapping.getBrowserType().getValue());
            }
        }
        return values.toArray(new String[values.size()]);
    }

    public String[] getLabelTypeIds() {
        return labelTypeIds;
    }

    public void setLabelTypeIds(String[] labelTypeIds) {
        this.labelTypeIds = labelTypeIds;
    }

    @Override
    public String[] getLabelTypeValues() {
        List<String> values = new ArrayList<String>();
        List<FileConfigToLabelTypeMapping> list = getFileConfigToLabelTypeMappingList();
        if (list != null && !list.isEmpty()) {
            for (FileConfigToLabelTypeMapping mapping : list) {
                values.add(mapping.getLabelType().getValue());
            }
        }
        return values.toArray(new String[values.size()]);
    }

    public String[] getRoleTypeIds() {
        return roleTypeIds;
    }

    public void setRoleTypeIds(String[] roleTypeIds) {
        this.roleTypeIds = roleTypeIds;
    }

    @Override
    public String[] getRoleTypeValues() {
        List<String> values = new ArrayList<String>();
        List<FileConfigToRoleTypeMapping> list = getFileConfigToRoleTypeMappingList();
        if (list != null && !list.isEmpty()) {
            for (FileConfigToRoleTypeMapping mapping : list) {
                values.add(mapping.getRoleType().getValue());
            }
        }
        return values.toArray(new String[values.size()]);
    }

    @Override
    public String getDocumentBoost() {
        return Float.valueOf(getBoost().floatValue()).toString();
    }

    @Override
    public String getIndexingTarget(String input) {
        if (includedDocPathPatterns == null) {
            initDocPathPattern();
        }

        for (Pattern pattern : includedDocPathPatterns) {
            if (pattern.matcher(input).matches()) {
                return Constants.TRUE;
            }
        }

        for (Pattern pattern : excludedDocPathPatterns) {
            if (pattern.matcher(input).matches()) {
                return Constants.FALSE;
            }
        }

        return Constants.TRUE;
    }

    protected void initDocPathPattern() {
        if (StringUtil.isNotBlank(getIncludedDocPaths())) {
            List<Pattern> pathPatterList = new ArrayList<Pattern>();
            String[] paths = getIncludedDocPaths().split("[\r\n]");
            for (String u : paths) {
                if (StringUtil.isNotBlank(u)) {
                    pathPatterList.add(Pattern.compile(u.trim()));
                }
            }
            includedDocPathPatterns = pathPatterList
                    .toArray(new Pattern[pathPatterList.size()]);
        } else {
            includedDocPathPatterns = new Pattern[0];
        }

        if (StringUtil.isNotBlank(getExcludedDocPaths())) {
            List<Pattern> pathPatterList = new ArrayList<Pattern>();
            String[] paths = getExcludedDocPaths().split("[\r\n]");
            for (String u : paths) {
                if (StringUtil.isNotBlank(u)) {
                    pathPatterList.add(Pattern.compile(u.trim()));
                }
            }
            excludedDocPathPatterns = pathPatterList
                    .toArray(new Pattern[pathPatterList.size()]);
        } else {
            excludedDocPathPatterns = new Pattern[0];
        }
    }

    public String getBoostValue() {
        if (_boost != null) {
            return Integer.toString(_boost.intValue());
        }
        return null;
    }

    public void setBoostValue(String value) {
        if (value != null) {
            try {
                _boost = new BigDecimal(value);
            } catch (Exception e) {
            }
        }
    }
}
